// AmpelPanel.java                              MM 2007
//                                              AZ 2006

import java.awt.*;                   // Color, Graphics
import javax.swing.*;                         // JPanel

/**
 * Ampelgrafik.
 */
public class AmpelPanel
  extends JPanel
{
/**
 * Ampelfarben.
 */
  private Color[] farben =
               { Color.red, Color.yellow, Color.green};

/**
 * Mathematisches Modell,
 * enthaelt Zustand der Ampel.
 */
  private AmpelModel model = null;

/**
 * Konstruktor, legt die Groesse des
 * Darstellungsbereichs fest.
 */
  public AmpelPanel( AmpelModel m)
  {
    model = m;
    setPreferredSize( new Dimension( 120, 185));
  }

/**
 * Zeichnen der Ampel.
 */
  public void paint( Graphics g)
  {
// Leeren des Darstellungsbereich
    g.setColor( getBackground());
    g.fillRect( 0, 0, getWidth(), getHeight());

// Zeichnen der Ampel
    for( int number = 0; number < 3; number++)
      setLight( g, number);
  }

/**
 * Zeichnen eines Ampellichtes.
 * @param g      Graphics
 * @param number Lichtnummer 0, 1, 2
 */
  private void setLight
  ( Graphics g, int number)
  {
// Groesse des aktuellen Fensters
    int width = getBounds().width;
    int height = getBounds().height;

// Kreisdurchmesser
    int diameter =
      Math.min( 2 * width / 3, height / 4);
    if( diameter < 20) diameter = 20;

// Abstand zwischen den Kreisen
    int gap = ( height - 3 * diameter) / 4;
    if( gap < 5) gap = 5;

// Abstand oben
    int distance = diameter + gap;

// Abstand links
    int left = ( width - diameter) / 2;

// Zeichnen des Ampellichtes
    g.setColor( model.getLight( number)? farben[ number]
                                       : Color.white);
    g.fillOval( left, gap + number * distance,
                diameter, diameter);
  }
}
